**Example 1: 回拨请求示例**



Input: 

```
tccli npp CreateCallBack --cli-unfold-argument  \
    --BizAppId xxx \
    --Src xxxx \
    --Dst xxxx \
    --BizId xxxxx
```

Output: 
```
{
    "Response": {
        "CallId": "xxxx",
        "DstDisplayNum": "",
        "ErrorCode": "0",
        "Msg": "",
        "RequestId": "0629205c-aa43-46ce-9251-1cc83b383eef",
        "SrcDisplayNum": ""
    }
}
```

